==> toutdoux-1.2.4.tar.gz: ToutDoux-1.2.4/core-plugins/communication_url/main.h <==
/*****************************************************************************/
/* main.h : Donnes globales et fentre principale
 * main.h : Global data and main window
 *
 *
 * Greffon ToutDoux : ouvrir un URL et enregistrer un URL
 * ToutDoux's plug-in : URL opening and URL saving 
 * Copyright (c) 2000 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@yahoo.com>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/

/*****************************************************************************/
/* Variables globales */
/*****************************************************************************/
GtkObject *mod; /* Module */
gboolean selection;
gboolean quit;
GtkWidget *entry;
int fin_wget;


/*****************************************************************************/
/* Module */
/*****************************************************************************/
GtkObject *plugins_about_def (void);
void mod_about (void);
GtkObject *mod_def (void);
void plugins_init (void);
gchar *plugins_show (void);
void plugins_hide (void);
void plugins_destroy (void);


/*****************************************************************************/
/* Wget */
/*****************************************************************************/
void *thread_wget (void * url);
void *thread_progression (void *taille);
gboolean plugins_load_url (gchar *url);

==> toutdoux-1.2.7.tar.gz: ToutDoux-1.2.7/core-plugins/communication_url/main.h <==
/*****************************************************************************/
/* main.h : Donnes globales et fentre principale
 * main.h : Global data and main window
 *
 *
 * Greffon ToutDoux : ouvrir un URL et enregistrer un URL
 * ToutDoux's plug-in : URL opening and URL saving 
 * Copyright (c) 2000-2001 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@toutdoux.org>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/

/*****************************************************************************/
/*** Variables globales - Global variables */
/*****************************************************************************/
GtkObject *mod;
gboolean selection;
gboolean quit;
GtkWidget *entry;
int fin_wget;

/*****************************************************************************/
/*** Module */
/*****************************************************************************/
GtkObject *plugins_about_def (void);
GtkObject *mod_def (void);
void plugins_init (void);
gchar *plugins_show (void);
void plugins_hide (void);
void plugins_destroy (gpointer user_data);
void radiobutton1_clicked (GtkRadioButton *radiobutton, gpointer user_data);
void radiobutton2_clicked (GtkRadioButton *radiobutton, gpointer user_data);

/*****************************************************************************/
/*** Commande - Command */
/*****************************************************************************/
void text_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data);
void history_select_child (GtkTree *tree, GtkWidget *widget, gpointer user_data);
void history_button_press_event (GtkWidget *widget, GdkEventButton *event, gpointer user_data);

/*****************************************************************************/
/*** Wget */
/*****************************************************************************/
gboolean plugins_load_url (gchar *url);
